@@ -1,4 +1,4 @@
-/* $Id: swap.h,v 1.23 2003/10/20 20:11:58 hadess Exp $ */
+/* $Id: swap.h,v 1.26 2006/04/18 20:17:25 gpoo Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -41,15 +41,16 @@ typedef struct _glibtop_swap	glibtop_swap;
 
 struct _glibtop_swap
 {
-	guint64	flags,
-		total,		/* GLIBTOP_SWAP_TOTAL	*/
-		used,		/* GLIBTOP_SWAP_USED	*/
-		free,		/* GLIBTOP_SWAP_FREE	*/
-		pagein,		/* GLIBTOP_SWAP_PAGEIN	*/
-		pageout;	/* GLIBTOP_SWAP_PAGEOUT	*/
+	guint64	flags;
+	guint64 total;		/* GLIBTOP_SWAP_TOTAL	*/
+	guint64 used;		/* GLIBTOP_SWAP_USED	*/
+	guint64 free;		/* GLIBTOP_SWAP_FREE	*/
+	guint64 pagein;		/* GLIBTOP_SWAP_PAGEIN	*/
+	guint64 pageout;	/* GLIBTOP_SWAP_PAGEOUT	*/
 };
 
-#define glibtop_get_swap(swap)	glibtop_get_swap_l(glibtop_global_server, swap)
+void
+glibtop_get_swap(glibtop_swap *buf);
 
 #if GLIBTOP_SUID_SWAP
 #define glibtop_get_swap_r		glibtop_get_swap_p
@@ -67,16 +68,6 @@ void glibtop_init_swap_s (glibtop *server);
 void glibtop_get_swap_s (glibtop *server, glibtop_swap *buf);
 #endif
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_swap [];
-extern const unsigned glibtop_types_swap [];
-extern const char *glibtop_labels_swap [];
-extern const char *glibtop_descriptions_swap [];
-
-#endif
 
 G_END_DECLS
 
